@@ -3,22 +3,23 @@ use crate::regs::Reg::{self, *};
 use crate::syscall_injection::StorageLocation;
 
 #[cfg(feature = "x86_64")]
-pub(crate) const FORK: target_ulong = 57;
+pub(crate) const VFORK: target_ulong = 58;
 
 #[cfg(feature = "i386")]
-pub(crate) const FORK: target_ulong = 2;
+pub(crate) const VFORK: target_ulong = 190;
 
 #[cfg(feature = "arm")]
-pub(crate) const FORK: target_ulong = 2;
+pub(crate) const VFORK: target_ulong = 190;
 
 #[cfg(feature = "aarch64")]
-pub(crate) const FORK: target_ulong = 220;
+pub(crate) const VFORK: target_ulong = 220;
 
+// TODO: mips needs to be changed to VFORK
 #[cfg(feature = "mips64")]
-pub(crate) const FORK: target_ulong = 5056;
+pub(crate) const VFORK: target_ulong = 5056;
 
 #[cfg(any(feature = "mips", feature = "mipsel"))]
-pub(crate) const FORK: target_ulong = 6056; // n32
+pub(crate) const VFORK: target_ulong = 6056; // n32
 
 pub(crate) const FORK_IS_CLONE: bool = cfg!(feature = "aarch64");
 
